onDeferredDeepLink method

void onDeferredDeepLink(
  1. DeferredDeepLinkCallback callback
)

Registers a callback for deferred deep links.

Deferred links are those that were clicked before the app was installed. If data is already available from a previous attribution call, the callback is invoked immediately in a microtask.

Implementation

void onDeferredDeepLink(DeferredDeepLinkCallback callback) {
  _deferredDeepLinkCallbacks.add(callback);

  if (_deferredDeepLinkDelivered) {
    Future.microtask(() => callback(_cachedDeferredDeepLink));
  }
}