peek method
Returns a snapshot of all events currently in the queue without removing them.
Implementation
List<EventRequest> peek() {
return List<EventRequest>.from(_queue);
}
Returns a snapshot of all events currently in the queue without removing them.
List<EventRequest> peek() {
return List<EventRequest>.from(_queue);
}