onDeepLink method

void onDeepLink(
  1. DeepLinkCallback callback
)

Sets a callback to be invoked when a direct deep link is opened.

Direct links are those clicked while the app is already installed.

Implementation

void onDeepLink(DeepLinkCallback callback) {
  if (!_isInitialized) {
    LinkFortyLogger.log('SDK not initialized. Call initialize() first.');
    return;
  }
  _deepLinkHandler?.onDeepLink(callback);
}