onDeferredDeepLink method

void onDeferredDeepLink(
  1. DeferredDeepLinkCallback callback
)

Sets a callback to be invoked when a deferred deep link is resolved.

Deferred links are those clicked before the app was installed.

Implementation

void onDeferredDeepLink(DeferredDeepLinkCallback callback) {
  if (!_isInitialized) {
    LinkFortyLogger.log('SDK not initialized. Call initialize() first.');
    return;
  }
  _deepLinkHandler?.onDeferredDeepLink(callback);
}