isDebugEnabled property

bool isDebugEnabled
getter/setter pair

Controls whether debug logging is enabled for the SDK.

This should typically be enabled only during development or when troubleshooting integration issues.

Implementation

static bool isDebugEnabled = false;