externalUserId property
Identifier for the app user creating the link (enables per-user deduplication and share attribution)
Implementation
final String? externalUserId;
Identifier for the app user creating the link (enables per-user deduplication and share attribution)
final String? externalUserId;