CreateLinkResult class

Result of creating a short link

Annotations
  • @JsonSerializable.new()

Constructors

CreateLinkResult({required String url, required String shortCode, required String linkId, bool? deduplicated})
Creates a link creation result
const
CreateLinkResult.fromJson(Map<String, dynamic> json)
JSON deserialization
factory

Properties

deduplicated bool?
True if an existing link was returned instead of creating a new one (per-user deduplication)
final
hashCode int
The hash code for this object.
no setteroverride
linkId String
Link UUID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortCode String
The generated short code
final
url String
Full shareable URL (e.g., "https://go.yourdomain.com/tmpl/abc123")
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
JSON serialization
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override