DashboardCreateLinkResponse class

Response from the dashboard link creation endpoint (POST /api/links) Maps the snake_case response to CreateLinkResult@JsonSerializable()

Annotations
  • @JsonSerializable.new()

Constructors

DashboardCreateLinkResponse({required String id, required String shortCode})
const
DashboardCreateLinkResponse.fromJson(Map<String, dynamic> json)
JSON deserialization
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
The id
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortCode String
The generated short code
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
JSON serialization
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override