attributedLinkId property
The deep link currently credited for this event (last-click). Null for organic activity (no deep link has opened the app).
Implementation
final String? attributedLinkId;
The deep link currently credited for this event (last-click). Null for organic activity (no deep link has opened the app).
final String? attributedLinkId;