attributionWindowHours property
Attribution window in hours (1-2160, default: 168 = 7 days).
How long after a click an install can be attributed.
Implementation
final int attributionWindowHours;
Attribution window in hours (1-2160, default: 168 = 7 days).
How long after a click an install can be attributed.
final int attributionWindowHours;