HttpClientImpl class

HTTP client implementation using the http package

Implemented types

Constructors

HttpClientImpl({Client? client, Duration timeout = const Duration(seconds: 30)})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

close() → void
execute({required String url, required HttpMethod method, Uint8List? body, Map<String, String>? headers}) Future<HttpResponse>
Executes an HTTP request and returns the raw response
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited