HttpMethod enum

HTTP methods supported by the SDK

Inheritance
Available extensions

Values

get → const HttpMethod
post → const HttpMethod
put → const HttpMethod
delete → const HttpMethod

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on HttpMethod, provided by the HttpMethodExtension extension

The string representation of the HTTP method
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HttpMethod>
A constant List of the values in this enum, in order of their declaration.