SharedPreferencesProtocol class abstract

Protocol for SharedPreferences to enable mocking in tests

Implementers

Constructors

SharedPreferencesProtocol()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBool(String key) → bool?
getString(String key) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<bool>
setBool(String key, bool value) → Future<bool>
setString(String key, String value) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited