SharedPreferencesWrapper class

Wrapper for SharedPreferences to conform to the protocol

Implemented types

Constructors

SharedPreferencesWrapper(SharedPreferences _prefs)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBool(String key) → bool?
override
getString(String key) → String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<bool>
override
setBool(String key, bool value) → Future<bool>
override
setString(String key, String value) → Future<bool>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited