StorageManagerProtocol class abstract

Protocol for dependency injection in tests

Implementers

Constructors

StorageManagerProtocol()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAll() → Future<bool>
getAttribution() → String?
getInstallData() → DeepLinkData?
getInstallId() → String?
isFirstLaunch() → bool
loadEventQueue() → List<EventRequest>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAttribution() → Future<bool>
saveAttribution(String json) → Future<bool>
saveEventQueue(List<EventRequest> events) → Future<bool>
saveInstallData(DeepLinkData data) → Future<bool>
saveInstallId(String installId) → Future<bool>
setHasLaunched() → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited