URLParser class

A utility class for extracting information from LinkForty deep link URLs.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractCustomParameters(Uri url) Map<String, String>
Extracts custom (non-UTM) query parameters from URL
extractShortCode(Uri url) String?
Extracts the short code from a URL path
extractUTMParameters(Uri url) UTMParameters?
Extracts UTM parameters from URL query
Parses a URL into DeepLinkData