ActiveAttribution class

The active last-click attribution: the deep link currently credited for in-app activity, and when it opened the app.

Constructors

ActiveAttribution({required String linkId, String? clickId, required String openedAt})
const
ActiveAttribution.fromJson(Map<String, dynamic> json)
factory

Properties

clickId String?
final
hashCode int
The hash code for this object.
no setterinherited
linkId String
final
openedAt String
ISO 8601 timestamp of when the deep link opened the app.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited