AttributionManager class

Manages app install attribution and initial deferred deep link retrieval.

This manager is responsible for identifying how a user first found and installed the app (e.g., via a specific LinkForty short link).

Constructors

AttributionManager({required NetworkManagerProtocol networkManager, required StorageManagerProtocol storageManager, required FingerprintCollectorProtocol fingerprintCollector})
Creates an attribution manager

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearData() → Future<void>
Clears all cached attribution data
getInstallData() → DeepLinkData?
Retrieves the cached install attribution data
getInstallId() → String?
Retrieves the install ID
isFirstLaunch() → bool
Checks if this is the first launch
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportInstall({required int attributionWindowHours, String? deviceId, String? appToken}) → Future<InstallResponse>
Reports a new app install to the LinkForty backend to retrieve attribution data.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited