EventTrackerProtocol class abstract
Protocol for EventTracker to enable mocking in tests
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- queuedEventCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearQueue(
) → void -
flushQueue(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
String name, [Map< String, dynamic> ? properties]) → Future<void> -
trackRevenue(
{required double amount, required String currency, Map< String, dynamic> ? properties}) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited