LinkFortyLogger class
Internal logger for the LinkForty SDK.
This logger is designed for internal SDK debugging and troubleshooting.
It only outputs logs to consoles when isDebugEnabled is set to true
via the LinkFortyConfig.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isDebugEnabled ↔ bool
-
Controls whether debug logging is enabled for the SDK.
getter/setter pair
Static Methods
-
info(
String message) → void -
Logs an informational
messageif isDebugEnabled istrue. -
log(
String message) → void -
Logs a debug
messageif isDebugEnabled istrue. -
logError(
String message, [Object? error, StackTrace? stackTrace]) → void -
Logs an error
message, optionalerrorandstackTraceif isDebugEnabled istrue. -
warning(
String message) → void -
Logs a warning
messageif isDebugEnabled istrue.