EventRequest class

Request payload for tracking events

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EventRequest({required String installId, required String eventName, required Map<String, dynamic> eventData, DateTime? timestamp})
Creates an event request
EventRequest.fromJson(Map<String, dynamic> json)
JSON deserialization
factory

Properties

eventData Map<String, dynamic>
Custom event properties (must be JSON-serializable)
final
eventName String
Name of the event (e.g., "purchase", "signup")
final
hashCode int
The hash code for this object.
no setteroverride
installId String
The install ID from attribution
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
ISO 8601 timestamp of when the event occurred
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
JSON serialization
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override