InstallResponse class

The server response containing attribution information for an app install.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

InstallResponse({required String installId, required bool attributed, required double confidenceScore, required List<String> matchedFactors, DeepLinkData? deepLinkData})
Creates an install response
const
InstallResponse.fromJson(Map<String, dynamic> json)
JSON deserialization
factory

Properties

attributed bool
Whether this install was attributed to a link click
final
confidenceScore double
Confidence score for attribution (0-100)
final
deepLinkData DeepLinkData?
Deep link data if attributed, null if organic
final
hashCode int
The hash code for this object.
no setteroverride
installId String
Identifies the unique app installation on the LinkForty backend.
final
matchedFactors List<String>
Which fingerprint factors matched
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
JSON serialization
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override