LinkFortyConfig class
Holds all configuration settings required to initialize the LinkForty SDK.
Constructors
Properties
- apiKey → String?
-
API key for LinkForty Cloud (optional for self-hosted Core).
final
- appToken → String?
-
Public workspace token (LinkForty Cloud).
final
- attributionWindowHours → int
-
Attribution window in hours (1-2160, default: 168 = 7 days).
final
- baseURL → Uri
-
The base URL of your LinkForty instance.
final
- debug → bool
-
Enable debug logging.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
validate(
) → void - Validates the configuration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override