UTMParameters class
Standard UTM parameters used for campaign tracking and analytics.
- Annotations
-
- @JsonSerializable.new()
Constructors
- UTMParameters({String? source, String? medium, String? campaign, String? term, String? content})
-
Creates UTM parameters
const
-
UTMParameters.fromJson(Map<
String, dynamic> json) -
JSON serialization
factory
Properties
- campaign → String?
-
Campaign name (e.g., "summer_sale", "product_launch")
final
- content → String?
-
Campaign content (e.g., "logolink", "textlink")
final
- hasAnyParameter → bool
-
Checks if any UTM parameter is set
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- medium → String?
-
Campaign medium (e.g., "cpc", "banner", "email")
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
Campaign source (e.g., "google", "facebook", "email")
final
- term → String?
-
Campaign term (e.g., "running+shoes")
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - JSON deserialization
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override