StorageKeys class
SharedPreferences/Storage keys used by the SDK
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- attribution → const String
- Active last-click attribution context key (ActiveAttribution JSON)
- eventQueue → const String
- Event queue key (JSON array of EventRequest)
- firstLaunch → const String
- First launch flag key
- installData → const String
- Install data key (DeepLinkData JSON)
- installId → const String
- Install ID key
- prefsName → const String
- SharedPreferences file name (Android-specific, not used in Flutter)