isFirstLaunch method
Checks if this is the first launch of the app
- Returns: True if this is the first launch, false otherwise
Implementation
@override
bool isFirstLaunch() {
// If the key doesn't exist, it defaults to null, so we check if it's not true
// We store "hasLaunched" and check if it's false
final hasLaunched = _prefs.getBool(StorageKeys.firstLaunch) ?? false;
return !hasLaunched;
}